==> anarchism_15.0.orig.tar.gz: afaq-15.0/markdown/new.md <==
# Introduction

Here is a list of all the new additions to the FAQ. An list of older changes
can found [here](oldnew.html).

The version number of the FAQ changes as follows. A major change results in
then the version number is increased by one (from version 10.2 to version 11,
for example). If a minor change is being made then the current version is
increased by 0.1 (for example, from version 10.2 to 10.3).

As far as new anarchist and libertarian links are concerned, we will add them
when we get enough to make an update worthwhile. These updates have no effect
on the FAQ version number as we don't want to inflate it higher than the
content deserves.

We hope that this makes it clear to visitors!

# What's New in the FAQ?

Version | Date | What's New  
---|---|---  
  
15.0

|

18-MAR-2014

|

[Reply to errors and distortions in David McNally's pamphlet "Socialism from
Below"](append31.html)  
Complete revision and expansion of the appendix _Reply to errors and
distortions in David McNally's pamphlet "Socialism from Below"_. This is to
include a significant expansion on refuting his account of Proudhon's ideas as
well as more information on both anarchism and Bolshevism.

This revision is the first since the publication of the second volume of the
FAQ.  
  
14.0

|

20-NOV-2012

|

[Introduction to Volume 2](vol2intro.html)  
Introduction to Volume 2 of _An Anarchist FAQ_

This revision is done to indicate that volume 2 has been published. It does
not signify a change of the main text of the work.  
  
  
  
14.0

|

08-MAR-2010

|

[Section J.4](secJ4.html)  
Revision of section on _"What trends in society aid anarchist activity?"_
Various sub-sections have been merged and renamed, along with significant
changes to content.

[Section J.5](secJ1.html)  
Substantial revision of section on _"What alternative social organisations do
anarchists create?"_. Lots of new material on anarchist community organising
and industrial struggles as well as on co-operatives. There is some re-
arranging of the material on mutual banking between sections, but no
significant changes.

[Section J.6](secJ2.html)  
Revision of section on _"What methods of child rearing do anarchists
advocate?"_. Various sub-sections have been merged and renamed, along with
significant changes to content.

[Section J.7](secJ7.html)  
Revision of section on _"What do anarchists mean by social revolution?"_. One
sub-section has been renamed, but no significant changes in content have been
made.

[Section J.2.8](secJ2.html)  
Slight change to the sub-section on _"J.2.8 Will abstentionism lead to the
right winning elections?"_ to include a quote from the late, great, Howard
Zinn.

This revision was made as part of getting the second volume of the FAQ ready
for publication. That is now complete.  
  
13.4

|

21-JAN-2010

|

[Section J](secJint.html)  
Revision of introduction to section J on _"What do Anarchists do?"_

[Section J.1](secJ1.html)  
Revision of section on _"J.1 Are anarchists involved in social struggles?"_.

[Section J.2](secJ2.html)  
Revision of section on _"What is direct action?"_.

[Section J.3](secJ3.html)  
Revision of section on _"J.3 What kinds of organisation do anarchists
build?"_.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.3

|

30-SEP-2009

|

[Section I.6](secI6.html)  
Revision of section on _"What about the "Tragedy of the Commons"?"_

[section I.7](secI7.html)  
Revision of section on _"Won't Libertarian Socialism destroy individuality?"_.

[section I.8](secI8.html)  
Revision of section on _"Does revolutionary Spain show that libertarian
socialism can work in practice?"_.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.2

|

18-AUG-2009

|

[Section I.4](secI4.html)  
Signification revision of section on _"How would an anarchist society
function?"_

[section I.5](secI5.html)  
Signification revision of section on _"What would the social structure of
anarchy look like?"_. Some sub-sections have been merged (the old I.5.10 and
I.5.11) and some have been substantially changed (the old I.5.13 and I.5.14
have been merged into the new I.5.11). Section I.5.3 has been renamed and its
previous material included in I.5.2. The new [section
I.5.3](secI5.html#seci533) discusses the means by which delegates remain under
control from below.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.1

|

18-JUN-2009

|

[Section I](secIcon.html)  
Signification revision of the [introduction](secIint.html) and first three
sub-sections ( [I.1](secI1.html), [I.2](secI2.html) and [I.3](secI3.html)) of
section I on **What would an anarchist society look like?**

[Section I.3.3](secI3.html#seci33)  
Complete revision of section I.3.3, which is now on **What is
socialisation?**.

[Section I.1.5](secI1.html#seci15)  
New section on **Does capitalism efficiently allocate resources?**, discussing
why attempts to portray socialism as _"impossible"_ downplay the allocative
inefficiencies of the current system.

[Appendix 3.1](append31.html)  
Slight change to the appendix _Reply to errors and distortions in David
McNally's pamphlet "Socialism from Below"_. This is to include [an
introduction](append31.html) which notes that McNally has now distanced
himself from this pamphlet as well as the addition of more quotes on party
dictatorship by Trotsky to the section 15 ([Did Trotsky keep alive Leninism's
_"democratic essence"_?](append31.html#app15)).

[An Anarchist FAQ blog](http://anarchism.pageabode.com/blogs/afaq)  
An Anarchist FAQ now has an official blog. This is used to post news as well
as extra material which cannot be included in the main body of the FAQ.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.0

|

11-NOV-2008

|

[An Anachist FAQ: Volume 1](book.html)  
**An Anarchist FAQ**, at long last, has now been published by AK Press. Volume 1 (introductions, sections A to F, plus the appendix on the symbols of Anarchy) is now available (ISBN: 978-1902593906)

[Section H](secHcon.html)  
Significant revision of the section on the anarchist critique of Marxism.
Removing of section H.2.15 as this is covered elsewhere in section H as well
as section H.2.16 (on the Spanish Revolution) as this is covered in [section
I.8.11](secI8.html#seci811).

[Section H.6](secH6.html)  
New section on the Russian Revolution, including an expansion of what were
sections H.3.15 and H.3.16 plus a new subsection on labour protest under Lenin
([Section H.6.3](secH6.html#sech63)).

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
12.2

|

08-FEB-2008

|

[The Symbols of Anarchy](append2.html)  
Significant revision and re-organisation of the appendix on the appendix on
the Symbols of Anarchy. Adding some new information, clarifying the roots of
the black and red-and-black flags in working class and generally improving it.

This revision was made as part of getting the first volume of the FAQ ready
for publication and so is really part of release 12.0  
  
12.1

|

27-OCT-2007

|

[Section G](secGcon.html)  
Significant revision, re-organisation and expansion of the section on
individualist anarchism. Expands in more depth why it is as anti-capitalist as
other kinds of anarchism. Special thanks to individualist anarchist Shawn
Wilbur for his comments and feedback on this revision.

The following revisions were made as part of getting the first volume of the
FAQ ready for publication and so are really part of release 12.0

[Section A.3.9](secA3.html#seca39)  
Revision of the section on primitivism to clarify a few issues.

[Section F.2.2](secF2.html#secf22)  
The addition of a few quotes by leading "anarcho"-capitalist Walter Block on
slave contracts. Which, in itself, shows how far that ideology is from genuine
anarchism.

This is part of the process of getting the FAQ ready for being published by AK
Press. Volume one (sections A to F, plus the introductions and appendix on the
symbols of anarchy) is nearly ready for publication. We will announce the
exact date later this year.  
  
12.0

|

19-JUL-2007

|

[Section C.7](secC7.html)  
Revision of section C.7 on what causes the capitalist business cycle.

[Section C.8](secC8.html)  
Revision of section C.8 on why state control of credit does not cause slumps
and the limitations of Keynesianism.

[Section C.9](secC9.html)  
Revision of section C.9 on what causes unemployment (and it is not high wages
or unions) and why the NAIRU is class warfare by the rich.

[Section F](secFcon.html)  
Revision of section F. Why "anarcho"-capitalism is not a form of anarchism.

[Section F.3.2](secF3.html#secf32)  
New section on why there cannot be harmony of interests in an unequal society.

[Introduction](intro.html)  
Slight changes to the original introduction.

[Tenth Anniversary of An Anarchist FAQ!](10years.html)  
Slight changes to the 10th Anniversay introduction.

[Bibliography](biblio.html)  
Slight reorganisation of the bibliography to include a new section on works
about anarchism and anarchists but written by non-libertarians.

This is part of the process of getting the FAQ ready for being published by AK
Press. Volume one (sections A to F, plus the introductions and appendix on the
symbols of anarchy) is now ready for publication. We will announce the exact
date soon.  
  
[‹ An Anarchist FAQ now published!](/afaq/book.html "Go to previous page" )
[up](/afaq/index.html "Go to parent page" ) [An Anarchist FAQ Introduction
›](/afaq/intro.html "Go to next page" )

==> anarchism_15.3.orig.tar.gz: afaq-15.3/markdown/new.md <==
# Introduction

Here is a list of all the new additions to the FAQ. An list of older changes
can found [here](oldnew.md).

The version number of the FAQ changes as follows. A major change results in
then the version number is increased by one (from version 10.2 to version 11,
for example). If a minor change is being made then the current version is
increased by 0.1 (for example, from version 10.2 to 10.3).

As far as new anarchist and libertarian links are concerned, we will add them
when we get enough to make an update worthwhile. These updates have no effect
on the FAQ version number as we don't want to inflate it higher than the
content deserves.

We hope that this makes it clear to visitors!

# What's New in the FAQ?

Version | Date | What's New  
---|---|---  
  
15.3

|

26-NOV-2019

|

[What caused the degeneration of the Russian Revolution?](append43.md)  
A revision of the appendix _What caused the degeneration of the Russian
Revolution?_ refuting the various Leninist attempts to blame the failure of
the Bolsheviks on "objective circumstances" (such as civil war, economic
disruption, etc.) rather than their ideology and the social structures they
favoured.  
  
15.2

|

19-JUL-2019

|

[Marxists and Spanish Anarchism](append32.md)  
A slight revision of the appendix _Marxists and Spanish Anarchism_ which
refutes various Marxist accounts of the Spanish Anarchist movement and key
episodes in its history. The changes are mostly improving various references,
indicating page numbers were possible of work previously referenced by URLs.
However, a few new passages have been added here and there in anticipation of
its full revision later.  
  
15.1

|

31-MAY-2018

|

[Were any of the Bolshevik oppositions a real alternative?](append45.md)  
A revision of the appendix _Were any of the Bolshevik oppositions a real
alternative?_ on various oppositional groups within Bolshevism and why they
were no alternative to mainstream Leninism and Stalinism (in the case of the
Left Opposition).

[What was the Kronstadt Rebellion? -- Did the rebellion involve new
sailors?](append42.md#app8)  
A slight revision of the sub-section of appendix _What was the Kronstadt
Rebellion?_ on whether the rebel sailors of 1921 had been there since 1917 or
not. The data showing that they were is re-arranged and better organised.  
  
15.0

|

18-MAR-2014

|

[Reply to errors and distortions in David McNally's pamphlet "Socialism from
Below"](append31.md)  
Complete revision and expansion of the appendix _Reply to errors and
distortions in David McNally's pamphlet "Socialism from Below"_. This is to
include a significant expansion on refuting his account of Proudhon's ideas as
well as more information on both anarchism and Bolshevism.

This revision is the first since the publication of the second volume of the
FAQ.  
  
14.0

|

20-NOV-2012

|

[Introduction to Volume 2](vol2intro.md)  
Introduction to Volume 2 of _An Anarchist FAQ_

This revision is done to indicate that volume 2 has been published. It does
not signify a change of the main text of the work.  
  
14.0

|

08-MAR-2010

|

[Section J.4](secJ4.md)  
Revision of section on _"What trends in society aid anarchist activity?"_
Various sub-sections have been merged and renamed, along with significant
changes to content.

[Section J.5](secJ1.md)  
Substantial revision of section on _"What alternative social organisations do
anarchists create?"_. Lots of new material on anarchist community organising
and industrial struggles as well as on co-operatives. There is some re-
arranging of the material on mutual banking between sections, but no
significant changes.

[Section J.6](secJ2.md)  
Revision of section on _"What methods of child rearing do anarchists
advocate?"_. Various sub-sections have been merged and renamed, along with
significant changes to content.

[Section J.7](secJ7.md)  
Revision of section on _"What do anarchists mean by social revolution?"_. One
sub-section has been renamed, but no significant changes in content have been
made.

[Section J.2.8](secJ2.md)  
Slight change to the sub-section on _"J.2.8 Will abstentionism lead to the
right winning elections?"_ to include a quote from the late, great, Howard
Zinn.

This revision was made as part of getting the second volume of the FAQ ready
for publication. That is now complete.  
  
13.4

|

21-JAN-2010

|

[Section J](secJint.md)  
Revision of introduction to section J on _"What do Anarchists do?"_

[Section J.1](secJ1.md)  
Revision of section on _"J.1 Are anarchists involved in social struggles?"_.

[Section J.2](secJ2.md)  
Revision of section on _"What is direct action?"_.

[Section J.3](secJ3.md)  
Revision of section on _"J.3 What kinds of organisation do anarchists
build?"_.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.3

|

30-SEP-2009

|

[Section I.6](secI6.md)  
Revision of section on _"What about the "Tragedy of the Commons"?"_

[section I.7](secI7.md)  
Revision of section on _"Won't Libertarian Socialism destroy individuality?"_.

[section I.8](secI8.md)  
Revision of section on _"Does revolutionary Spain show that libertarian
socialism can work in practice?"_.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.2

|

18-AUG-2009

|

[Section I.4](secI4.md)  
Signification revision of section on _"How would an anarchist society
function?"_

[section I.5](secI5.md)  
Signification revision of section on _"What would the social structure of
anarchy look like?"_. Some sub-sections have been merged (the old I.5.10 and
I.5.11) and some have been substantially changed (the old I.5.13 and I.5.14
have been merged into the new I.5.11). Section I.5.3 has been renamed and its
previous material included in I.5.2. The new [section
I.5.3](secI5.md#seci533) discusses the means by which delegates remain under
control from below.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.1

|

18-JUN-2009

|

[Section I](secIcon.md)  
Signification revision of the [introduction](secIint.md) and first three
sub-sections ( [I.1](secI1.md), [I.2](secI2.md) and [I.3](secI3.md)) of
section I on **What would an anarchist society look like?**

[Section I.3.3](secI3.md#seci33)  
Complete revision of section I.3.3, which is now on **What is
socialisation?**.

[Section I.1.5](secI1.md#seci15)  
New section on **Does capitalism efficiently allocate resources?** ,
discussing why attempts to portray socialism as _"impossible"_ downplay the
allocative inefficiencies of the current system.

[Appendix 3.1](append31.md)  
Slight change to the appendix _Reply to errors and distortions in David
McNally's pamphlet "Socialism from Below"_. This is to include [an
introduction](append31.md) which notes that McNally has now distanced
himself from this pamphlet as well as the addition of more quotes on party
dictatorship by Trotsky to the section 15 ([Did Trotsky keep alive Leninism's
_"democratic essence"_?](append31.md#app15)).

An Anarchist FAQ now has an official blog. This is used to post news as well
as extra material which cannot be included in the main body of the FAQ.

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
13.0

|

11-NOV-2008

|

[An Anachist FAQ: Volume 1](book.md)  
**An Anarchist FAQ** , at long last, has now been published by AK Press.
Volume 1 (introductions, sections A to F, plus the appendix on the symbols of
Anarchy) is now available (ISBN: 978-1902593906)

[Section H](secHcon.md)  
Significant revision of the section on the anarchist critique of Marxism.
Removing of section H.2.15 as this is covered elsewhere in section H as well
as section H.2.16 (on the Spanish Revolution) as this is covered in [section
I.8.11](secI8.md#seci811).

[Section H.6](secH6.md)  
New section on the Russian Revolution, including an expansion of what were
sections H.3.15 and H.3.16 plus a new subsection on labour protest under Lenin
([Section H.6.3](secH6.md#sech63)).

This revision was made as part of getting the second volume of the FAQ ready
for publication.  
  
12.2

|

08-FEB-2008

|

[The Symbols of Anarchy](append2.md)  
Significant revision and re-organisation of the appendix on the appendix on
the Symbols of Anarchy. Adding some new information, clarifying the roots of
the black and red-and-black flags in working class and generally improving it.

This revision was made as part of getting the first volume of the FAQ ready
for publication and so is really part of release 12.0  
  
12.1

|

27-OCT-2007

|

[Section G](secGcon.md)  
Significant revision, re-organisation and expansion of the section on
individualist anarchism. Expands in more depth why it is as anti-capitalist as
other kinds of anarchism. Special thanks to individualist anarchist Shawn
Wilbur for his comments and feedback on this revision.

The following revisions were made as part of getting the first volume of the
FAQ ready for publication and so are really part of release 12.0

[Section A.3.9](secA3.md#seca39)  
Revision of the section on primitivism to clarify a few issues.

[Section F.2.2](secF2.md#secf22)  
The addition of a few quotes by leading "anarcho"-capitalist Walter Block on
slave contracts. Which, in itself, shows how far that ideology is from genuine
anarchism.

This is part of the process of getting the FAQ ready for being published by AK
Press. Volume one (sections A to F, plus the introductions and appendix on the
symbols of anarchy) is nearly ready for publication. We will announce the
exact date later this year.  
  
12.0

|

19-JUL-2007

|

[Section C.7](secC7.md)  
Revision of section C.7 on what causes the capitalist business cycle.

[Section C.8](secC8.md)  
Revision of section C.8 on why state control of credit does not cause slumps
and the limitations of Keynesianism.

[Section C.9](secC9.md)  
Revision of section C.9 on what causes unemployment (and it is not high wages
or unions) and why the NAIRU is class warfare by the rich.

[Section F](secFcon.md)  
Revision of section F. Why "anarcho"-capitalism is not a form of anarchism.

[Section F.3.2](secF3.md#secf32)  
New section on why there cannot be harmony of interests in an unequal society.

[Introduction](intro.md)  
Slight changes to the original introduction.

[Tenth Anniversary of An Anarchist FAQ!](10years.md)  
Slight changes to the 10th Anniversay introduction.

[Bibliography](biblio.md)  
Slight reorganisation of the bibliography to include a new section on works
about anarchism and anarchists but written by non-libertarians.

This is part of the process of getting the FAQ ready for being published by AK
Press. Volume one (sections A to F, plus the introductions and appendix on the
symbols of anarchy) is now ready for publication. We will announce the exact
date soon.  
  
[‹ An Anarchist FAQ now published!](book.md "Go to previous page")
[up](index.md "Go to parent page") [An Anarchist FAQ Introduction
›](intro.md "Go to next page")
